@@ -68,7 +68,7 @@ def fetch_delayed_crypto_daily_data(frequence = 'daily', ssj=None, local_root_di
 
     freqly_pkl_file_name_suffix = f'_{frequence}_returns.pkl'
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
-    saving_return_path = f'{local_root_directory}{ssj}_{dates_stub}_{delay}_{freqly_pkl_file_name_suffix}'
+    saving_return_path = f'{local_root_directory}{ssj}_{dates_stub}_{delay}{freqly_pkl_file_name_suffix}'
     daily_crypto_df.to_pickle(saving_return_path)
     return daily_crypto_df
 
